intelmq.bots.experts.format_field package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.format_field package

## Submodules

## intelmq.bots.experts.format_field.expert module

`intelmq.bots.experts.format_field.expert.` `BOT`

  alias of `intelmq.bots.experts.format_field.expert.FormatFieldExpertBot`

class `intelmq.bots.experts.format_field.expert.` `FormatFieldExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Perform string method operations on column values

  `init`()
  `new_value` = ''
  `old_value` = ''
  `process`()
  `replace_column` = ''
  `replace_count` = 1
  `split_column` = None
  `split_separator` = ','
  `strip_chars` = ' '
  `strip_columns` = ''

## Module contents